@@ -1,6 +1,6 @@
 import requests
 
-class Robot:
+class robot:
     def __init__(self,name,qq_num,APIport,token):
         self.name = name
         self.qq_num = str(qq_num)
@@ -17,3 +17,4 @@ class Robot:
         result=raw_result.text
         if print_result == True:
             print(result)
+        return raw_result
